.. pywwt documentation master file, created by
   sphinx-quickstart on Mon Dec  4 10:41:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pywwt: WorldWide Telescope from Python
======================================

About
-----

`WorldWide Telescope
<http://worldwidetelescope.org/home>`_ is a free and powerful viewer developed
by the American Astronomical Society than can display astronomical and planetary
data. The two main versions of WorldWide Telescope are a web client, which works
across all platforms, and a Windows desktop application. WorldWide Telescope is
designed to be useful to a wide audience, including researchers, educators, and
the general public.

The pywwt package aims to make it easy to use WorldWide Telescope from Python,
and includes the following:

* A `Jupyter <http://jupyter.org>`_ notebook/lab widget
* A standalone Qt viewer/widget
* A client for the Windows version of WorldWide Telescope

This package is still under development and the functionality will be expanded
over the coming weeks/months. Please do let us know if you try it out and run
into any issues (see `Getting help`_).

Quick start
-----------

If you want to try out the WorldWide Telescope Jupyter widget without installing
anything locally, you can do so by viewing an example Jupyter notebook online
`at mybinder.org <https://mybinder.org/v2/gh/WorldWideTelescope/pywwt-notebooks/master?filepath=pywwt_jupyter.ipynb>`_.

User guide
----------

.. toctree::
   :maxdepth: 1

   installation
   jupyter
   qt
   settings
   annotations
   windows
   api

Getting help
------------

If you run into any issues when using pywwt, please open an issue
`here <https://github.com/WorldWideTelescope/pywwt/issues>`_.

Acknowledgments
---------------

This work is funded through the American Astronomical Society WorldWide Telescope
project.
